@@ -44,7 +44,7 @@ def runserver(host, port):
 def sync_customers():
     """Udpate customers from CRM"""
     LOGS.logger.info("Sync customers from CRM -- START")
-    products = ["business_access", "business_plus", "airfiber"]
+    products = ["business_access", "business_plus"] #, "airfiber"]
     for product in products:
         customers = core.get_customers_crm(product)
         for customer in customers:
