@@ -229,8 +229,8 @@ def update_customer(customer_name, product_name, primary_ref):
     Updates a customer in fup-services database
     """
     sql = (
-        "UPDATE customer SET refnum={ref}, product={product}"
-        "WHERE name={name};"
+        "UPDATE customer SET refnum='{ref}', product='{product}'"
+        "WHERE name='{name}';"
         .format(ref=primary_ref, name=customer_name, product=product_name)
     )
     try:
